package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.ElecValencyStrategy;

import java.util.List;

/**
 * 电价策略Mapper接口
 *
 * @author ruoyi
 * @date 2024-07-23
 */
public interface ElecValencyStrategyMapper {
    /**
     * 查询电价策略
     *
     * @param id 电价策略主键
     * @return 电价策略
     */
    ElecValencyStrategy selectElecValencyStrategyById(Long id);

    /**
     * 查询电价策略列表
     *
     * @param sysElectrovalencyStrategy 电价策略
     * @return 电价策略集合
     */
    List<ElecValencyStrategy> selectElecValencyStrategyList(ElecValencyStrategy sysElectrovalencyStrategy);

    /**
     * 新增电价策略
     *
     * @param sysElectrovalencyStrategy 电价策略
     * @return 结果
     */
    int insertElecValencyStrategy(ElecValencyStrategy sysElectrovalencyStrategy);

    /**
     * 修改电价策略
     *
     * @param sysElectrovalencyStrategy 电价策略
     * @return 结果
     */
    int updateElecValencyStrategy(ElecValencyStrategy sysElectrovalencyStrategy);

    /**
     * 删除电价策略
     *
     * @param id 电价策略主键
     * @return 结果
     */
    int deleteElecValencyStrategyById(Long id);

    /**
     * 批量删除电价策略
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteElecValencyStrategyByIds(Long[] ids);
}
